Library Reference
=================

.. toctree::
   :hidden:
   :maxdepth: 2

   doc
   abc
   header
   term
   typedef
   id
   pv
   syn
   xref
   exceptions


.. currentmodule:: fastobo
.. automodule:: fastobo


Functions
---------

.. autofunction:: fastobo.dump_graph

.. autofunction:: fastobo.dump_owl

.. autofunction:: fastobo.iter

.. autofunction:: fastobo.load

.. autofunction:: fastobo.loads

.. autofunction:: fastobo.load_graph

.. autofunction:: fastobo.id.is_valid

.. autofunction:: fastobo.id.parse


Data structures
---------------

Document (`fastobo.doc`)
^^^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.doc
.. autosummary::
    :nosignatures:

    OboDoc


Abstract Base Classes (`fastobo.abc`)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.abc
.. autosummary::
    :nosignatures:

    AbstractClause
    AbstractEntityClause
    AbstractFrame
    AbstractEntityFrame



Identifier (`fastobo.id`)
^^^^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.id
.. autosummary::
    :nosignatures:

    BaseIdent
    PrefixedIdent
    UnprefixedIdent
    Url


Header (`fastobo.header`)
^^^^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.header
.. autosummary::
   :nosignatures:

   HeaderFrame
   BaseHeaderClause

   FormatVersionClause
   DataVersionClause
   DateClause
   SavedByClause
   AutoGeneratedByClause
   ImportClause
   SubsetdefClause
   SynonymTypedefClause
   DefaultNamespaceClause
   IdspaceClause
   TreatXrefsAsEquivalentClause
   TreatXrefsAsGenusDifferentiaClause
   TreatXrefsAsReverseGenusDifferentiaClause
   TreatXrefsAsRelationshipClause
   TreatXrefsAsIsAClause
   TreatXrefsAsHasSubclassClause
   PropertyValueClause
   RemarkClause
   OntologyClause
   OwlAxiomsClause
   UnreservedClause


Term (`fastobo.term`)
^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.term
.. autosummary::
   :nosignatures:

   TermFrame
   BaseTermClause

   AltIdClause
   BuiltinClause
   CommentClause
   ConsiderClause
   CreatedByClause
   CreationDateClause
   DefClause
   DisjointFromClause
   EquivalentToClause
   IntersectionOfClause
   IsAClause
   IsAnonymousClause
   IsObsoleteClause
   NameClause
   NamespaceClause
   PropertyValueClause
   RelationshipClause
   ReplacedByClause
   SubsetClause
   SynonymClause
   UnionOfClause
   XrefClause


Typedef (`fastobo.typedef`)
^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.typedef
.. autosummary::
   :nosignatures:

   TypedefFrame
   BaseTypedefClause

   AltIdClause
   BuiltinClause
   CommentClause
   ConsiderClause
   CreatedByClause
   CreationDateClause
   DefClause
   DisjointFromClause
   DisjointOverClause
   DomainClause
   EquivalentToChainClause
   EquivalentToClause
   ExpandAssertionToClause
   ExpandExpressionToClause
   HoldsOverChainClause
   IntersectionOfClause
   InverseOfClause
   IsAClause
   IsAnonymousClause
   IsAntiSymmetricClause
   IsAsymmetricClause
   IsClassLevelClause
   IsCyclicClause
   IsFunctionalClause
   IsInverseFunctionalClause
   IsMetadataTagClause
   IsObsoleteClause
   IsReflexiveClause
   IsSymmetricClause
   IsTransitiveClause
   NameClause
   NamespaceClause
   PropertyValueClause
   RangeClause
   RelationshipClause
   ReplacedByClause
   SubsetClause
   SynonymClause
   TransitiveOverClause
   UnionOfClause
   XrefClause


Property Value (`fastobo.pv`)
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.pv
.. autosummary::
   :nosignatures:

   AbstractPropertyValue
   LiteralPropertyValue
   ResourcePropertyValue


Synonym (`fastobo.syn`)
^^^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.syn
.. autosummary::
   :nosignatures:

   Synonym


Xref (`fastobo.xref`)
^^^^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.xref
.. autosummary::
    :nosignatures:

    Xref
    XrefList



Exceptions
----------

Cardinality Errors
^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.exceptions
.. autosummary::
   :nosignatures:

   MissingClauseError
   DuplicateClausesError
   SingleClauseError


Threading Errors
^^^^^^^^^^^^^^^^^^

.. currentmodule:: fastobo.exceptions
.. autosummary::
   :nosignatures:

   DisconnectedChannelError
